@@ -17,7 +17,7 @@ import numpy as np
 
 class lines:
 	"""A class that generates basic line plots"""
-	def __init__(self, title_font=16, xfont=16, yfont=16, figsize=(6, 6)):
+	def __init__(self, title_font=16, xfont=16, yfont=16, figsize=None):
 		"""calculates the probability that "token" is found in spam emails
 		
 		:param token: (str)
@@ -27,7 +27,7 @@ class lines:
 		self.xfont = xfont
 		self.yfont = yfont
 		self.already_called_plot_line = False
-		plt.figure(figsize=figsize)
+		if figsize is not None: plt.figure(figsize=figsize)
 
 	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
