@@ -6,7 +6,7 @@ import numpy as np
 
 class scatter:
 	"""A class that generates basic scatter plots"""
-	def __init__(self, title_font=16, xfont=16, yfont=16, figsize=(6, 6)):
+	def __init__(self, title_font=16, xfont=16, yfont=16, figsize=None):
 		"""calculates the probability that "token" is found in spam emails
 		
 		:param token: (str)
@@ -16,7 +16,7 @@ class scatter:
 		self.xfont = xfont
 		self.yfont = yfont
 		self.already_called_plot_line = False
-		plt.figure(figsize=figsize)
+		if figsize is not None: plt.figure(figsize=figsize)
 
 	def plot_scatter(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
@@ -83,10 +83,20 @@ class scatter:
 
 		plt.scatter(X, Y, color=color)
 
-	def show(self, save_path=None):
+	def show(self, save_path=None, title='', xlabel='', ylabel='', imgText=None, 
+					xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
+					xTextLoc=None, yTextLoc=None):
+
+
 		if save_path is None: plt.show()
 		else: plt.savefig(save_path)
 
+		self.set_title(title, fontsize=self.title_font)
+		self.set_xlabel(xlabel, fontsize=self.xfont)
+		self.set_ylabel(ylabel, fontsize=self.yfont)
+		if imgText is not None:
+			self.add_text(X, Y, imgText, α=xTextShift, β=yTextShift, xTextLoc=xTextLoc, yTextLoc=yTextLoc)
+
 
 	def plot_line_with_error_area(x, y, error, show=False):
 		#x = np.linspace(0, 30, 30)
